@@ -59,7 +59,10 @@ class GeometricalStructure:
         if Tags.PRIORITY in single_structure_settings:
             self.priority = single_structure_settings[Tags.PRIORITY]
 
-        self.partial_volume = single_structure_settings[Tags.CONSIDER_PARTIAL_VOLUME]
+        if Tags.CONSIDER_PARTIAL_VOLUME in single_structure_settings:
+            self.partial_volume = single_structure_settings[Tags.CONSIDER_PARTIAL_VOLUME]
+        else:
+            self.partial_volume = False
 
         self.molecule_composition = single_structure_settings[Tags.MOLECULE_COMPOSITION]
         self.molecule_composition.update_internal_properties()
